==> libexplain_0.11.D001.orig.tar.gz: libexplain-0.11.D001/test/03/t0327a.sh <==
#!/bin/sh
#
# libexplain - Explain errno values returned by libc functions
# Copyright (C) 2008, 2009 Peter Miller
# Written by Peter Miller <pmiller@opensource.org.au>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
#

TEST_SUBJECT="accept EOPNOTSUPP"
. test_prelude

fmt > test.ok << 'fubar'
accept(fildes = 42, sock_addr = 0xNNNNNNNN, sock_addr_size = { 128 })
failed, Operation not supported (EOPNOTSUPP) because the socket is not
of a type that supports the accept(2) system call
fubar
test $? -eq 0 || no_result

explain -e EOPNOTSUPP accept 42 > test.out4
test $? -eq 0 || fail

fmt -w700 test.out4 > test.out3
test $? -eq 0 || no_result

sed 's|0x........|0xNNNNNNNN|g' test.out3 > test.out2
test $? -eq 0 || no_result

fmt  test.out2 > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

# vim:ts=8:sw=4:et

==> libexplain_0.19.D001.orig.tar.gz: libexplain-0.19.D001/test/03/t0327a.sh <==
#!/bin/sh
#
# libexplain - Explain errno values returned by libc functions
# Copyright (C) 2008, 2009 Peter Miller
# Written by Peter Miller <pmiller@opensource.org.au>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
#

TEST_SUBJECT="accept EOPNOTSUPP"
. test_prelude

fmt > test.ok << 'fubar'
accept(fildes = 42, sock_addr = 0xNNNNNNNN, sock_addr_size = { 128 })
failed, Operation not supported (EOPNOTSUPP) because the socket is not
of a type that supports the accept system call
fubar
test $? -eq 0 || no_result

explain -e EOPNOTSUPP accept 42 > test.out4
test $? -eq 0 || fail

fmt -w700 test.out4 > test.out3
test $? -eq 0 || no_result

sed 's|0x........|0xNNNNNNNN|g' test.out3 > test.out2
test $? -eq 0 || no_result

fmt  test.out2 > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

# vim:ts=8:sw=4:et
